Python Utilities
================

This repo collects some small Python utilities that I have created (or collected) in practice,
and organizes them as a package named `zpz`.

These utilities are not "one-off" experiments; they are really useful code.
However, they do not form a coherent set of utilities for a particular application domain.
It's reasonable to consider it to be mainly for the author's personal conveniences.
However, I also refrain from making arbitrary, unnecessary breaking changes.
New releases are made on an as-needed basis.

To install, do

```
pip install zpz
```

There are some optional dependencies for specific modules.
